package com.jqtx.windows.command;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.web.request.RiskCreditRequest;
import com.jqtx.windows.web.response.JsonResult;
import com.jqtx.windows.web.response.LoanSubmitResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Set;

@Service
@Slf4j
public class RiskQueryDataCommand extends AbstractCommand {
    @Autowired

    private CreditComponent creditComponent;
    @Autowired
    private OssUtils ossUtils;

    public JsonResult execute() {
        String request = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        RiskCreditRequest riskCreditRequest = JSON.parseObject(request, RiskCreditRequest.class);
        CreditModel creditModel = null;
        if (riskCreditRequest.getOrderNo() == null) {
            creditModel = creditComponent.getByCertNo(riskCreditRequest.getCertNo());
        } else {
            creditModel = creditComponent.getByOrderNo(riskCreditRequest.getOrderNo());
        }
        if (StringUtils.isNotEmpty(creditModel.getCreditThirdUrl())) {
            String data = ossUtils.getStringObject(creditModel.getCreditThirdUrl());
            JSONObject jsonObject = JSONObject.parseObject(data);
            return JsonResult.success(jsonObject.getJSONObject(riskCreditRequest.getApiCode()));
        } else {
            return JsonResult.success();
        }


    }

    public static void main(String[] args) {
        String a = "{\"TENCENT_FRAUD_SUMMIT\":{\"flag\":\"1\",\"data\":{\"Response\":{\"RequestId\":\"ca79863d-714e-4578-85ba-f3d4f0a7b14c\",\"Data\":{\"Message\":\"Success\",\"PostTime\":\"1650026831\",\"CodeDesc\":\"Success\",\"RiskScore\":\"62\",\"ExtensionOut\":\"\",\"Found\":\"1\",\"IdFound\":\"1\",\"Code\":\"0\",\"RiskInfo\":[],\"OtherModelScores\":[]}}},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022599057\",\"comprs\":\"0\"},\"BAIRONG_APPLYFEATURE\":{\"code\":\"100002\",\"swift_number\":\"3031389_20231024192024_6960\",\"queryTime\":\"2023-10-24 19:20:24\",\"message\":\"未预埋数据,请联系对接的交付人员\"},\"HAODUOSHU_RISK\":{\"msg\":\"OK\",\"errorType\":\"0\",\"queryTime\":\"2023-10-24 19:20:27\",\"content\":{\"hds_36m_total_purchse_money\":\"114\",\"hds_36m_doub11_12_purchase_cnt\":\"0\",\"hds_month_cnt_from_recent_purchase_time\":\"3\",\"hds_36m_doub11_12_total_purchase_money\":\"0\",\"hds_36m_month_max_purchase_cnt_excp_doub11_12\":\"4\",\"hds_36m_month_max_purchase_money_excp_doub11_12\":\"28\",\"total_TmallID_cnt\":\"1\",\"hds_36m_day_max_purchase_money_excp_doub11_12\":\"28\",\"hds_month_cnt_from_most_early_purchase_time\":\"21\",\"hds_36m_day_max_purchase_cnt_excp_doub11_12\":\"4\",\"hds_pay_record_month_cnt\":\"5\",\"cust_aging_rank\":\"1\",\"hds_6m_total_purchase_cnt\":\"3\",\"hds_36m_total_purchase_cnt\":\"10\",\"cust_rich_rank\":\"3\",\"hds_36m_purchase_steady\":\"0.2793277776858008\",\"addr_rich_rank\":\"2\",\"total_otherPlatform_cnt\":\"1\"}},\"BAIRONG_SPECIALLIST\":{\"rs_strategy_id\":\"STR_BR0004751\",\"code\":\"100002\",\"flag_specialList_c\":\"0\",\"swift_number\":\"3031772_20231024192023_59001CC3A19\",\"rs_product_type\":\"100081\",\"rs_Rule_weight\":\"\",\"rs_platform\":\"web\",\"rs_final_decision\":\"\",\"rs_Rule_decision\":\"\",\"flag_riskstrategy\":\"0\",\"Rule_final_weight\":\"\",\"rs_product_name\":\"预置_反欺诈规则-特殊名单验证\",\"queryTime\":\"2023-10-24 19:20:24\",\"flag_rulespeciallist_c\":\"0\",\"rs_strategy_version\":\"1.0\",\"Rule_final_decision\":\"\",\"rs_scene\":\"lend\"},\"PD_XINYAN_PAY_EX\":{\"flag\":\"1\",\"data\":{\"data\":{\"code\":\"0\",\"versions\":\"2.0.0\",\"fee\":\"z\",\"trade_no\":\"20230317113720285000016165119736\",\"trans_id\":\"055798b4c47511\",\"result_detail\":{\"B22170019\":\"16\",\"B22170050\":\"(0,7]\",\"B22170053\":\"630\",\"B22170010\":\"[50000,+)\",\"B22170054\":\"2023-03\",\"B22170051\":\"85\",\"B22170052\":\"44\",\"B22170013\":\"11\",\"B22170014\":\"18\",\"B22170011\":\"[50000,+)\",\"B22170012\":\"2\",\"B22170017\":\"8\",\"B22170018\":\"15\",\"B22170015\":\"1\",\"B22170016\":\"4\",\"B22170020\":\"22\",\"B22170021\":\"16\",\"B22170024\":\"0\",\"B22170025\":\"1\",\"B22170022\":\"22\",\"B22170023\":\"0\",\"B22170028\":\"0\",\"B22170029\":\"0\",\"B22170026\":\"1\",\"B22170027\":\"1\",\"B22170031\":\"[500,1000)\",\"B22170032\":\"[500,1000)\",\"B22170030\":\"0\",\"B22170035\":\"3\",\"B22170036\":\"8\",\"B22170033\":\"[500,1000)\",\"B22170034\":\"96%\",\"B22170039\":\"14\",\"B22170037\":\"9\",\"B22170038\":\"11\",\"B22170008\":\"[50000,+)\",\"B22170009\":\"[50000,+)\",\"B22170042\":\"[50000,+)\",\"B22170043\":\"[50000,+)\",\"B22170040\":\"[10000,20000)\",\"B22170041\":\"[20000,30000)\",\"B22170002\":\"4\",\"B22170046\":\"36\",\"B22170003\":\"14\",\"B22170047\":\"72\",\"B22170044\":\"[50000,+)\",\"B22170001\":\"535\",\"B22170045\":\"12\",\"B22170006\":\"45\",\"B22170007\":\"[20000,30000)\",\"B22170004\":\"29\",\"B22170048\":\"97\",\"B22170005\":\"32\",\"B22170049\":\"139\"},\"desc\":\"查询成功\"},\"success\":true},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022785001\",\"comprs\":\"0\"},\"PD_ALI_YOUMENG_SCORE\":{\"flag\":\"1\",\"data\":{\"code\":\"0\",\"success\":true,\"response\":{\"req_id\":\"9782f710c57a4d9ab0ba93ad6cf4ded6\",\"biz_id\":\"2032739d-68a4-4c02-9075-d87851921058\",\"tags\":{\"credit_score\":\"526\"}},\"message\":\"OK\"},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:24\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022119470\",\"comprs\":\"0\"},\"PD_XINYAN_PAY_INDEX\":{\"flag\":\"1\",\"data\":{\"data\":{\"code\":\"0\",\"versions\":\"1.4.0\",\"fee\":\"Y\",\"trade_no\":\"20230802143235151000000011344351\",\"trans_id\":\"20230802143229900347\",\"result_detail\":{\"A22160009\":\"15\",\"A22160008\":\"5\",\"A22160007\":\"2020-01\",\"A22160006\":\"295\",\"A22160005\":\"68\",\"A22160004\":\"57\",\"A22160003\":\"128\",\"A22160002\":\"74\",\"A22160001\":\"496\",\"A22160010\":\"45\"},\"desc\":\"查询成功\"},\"success\":true},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022730711\",\"port_pay_behavior_ex_fmlh\":{\"flag\":\"1\",\"resp_cd\":\"000000\",\"resp_msg\":\"处理成功\"},\"comprs\":\"0\"},\"BAIRONG_SCORECUST_3\":{\"code\":\"100002\",\"swift_number\":\"3031389_20231024192023_6958\",\"queryTime\":\"2023-10-24 19:20:23\",\"message\":\"未预埋数据,请联系对接的交付人员\"},\"TENCENT_FRAUD_VIP\":{\"flag\":\"1\",\"data\":{\"Response\":{\"RequestId\":\"ca79863d-714e-4578-85ba-f3d4f0a7b14c\",\"Data\":{\"Message\":\"Success\",\"PostTime\":\"1650026831\",\"CodeDesc\":\"Success\",\"RiskScore\":\"62\",\"ExtensionOut\":\"\",\"Found\":\"1\",\"IdFound\":\"1\",\"Code\":\"0\",\"RiskInfo\":[],\"OtherModelScores\":[]}}},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022440507\",\"comprs\":\"0\"},\"BAIHANG_ACCESS_SUMMIT\":{\"workInfo\":[],\"revolvingLoan\":{\"D30\":{\"accountCount\":\"0\",\"revolvingCompensationCount\":\"0\",\"revolvingCompensationAmount\":\"0.00\",\"creditLimitSum\":\"0.00\",\"revolvingCompensationTimes\":\"0\",\"overdueAccountCount\":\"0\",\"applyTenantCount\":\"0\",\"lendingAmount\":\"0.00\"},\"summary\":{\"remainingAmount\":\"0.00\",\"remainingOverdueAmount\":\"0.00\",\"revolvingLastCompensationDate\":\"\",\"accountCount\":\"2\",\"remainingMaxOverdueStatus\":\"N\",\"creditLimitSum\":\"60000.00\",\"validAccountCount\":\"2\",\"remainingOverdueAccountCount\":\"0\",\"maxOverdueStatus\":\"N\",\"maxCreditLimitPerTenant\":\"30000.00\",\"overdueCount\":\"0\"},\"D360\":{\"accountCount\":\"2\",\"revolvingCompensationCount\":\"0\",\"revolvingCompensationAmount\":\"0.00\",\"creditLimitSum\":\"60000.00\",\"revolvingCompensationTimes\":\"0\",\"overdueAccountCount\":\"0\",\"applyTenantCount\":\"0\",\"lendingAmount\":\"0.00\"},\"D180\":{\"accountCount\":\"2\",\"revolvingCompensationCount\":\"0\",\"revolvingCompensationAmount\":\"0.00\",\"creditLimitSum\":\"60000.00\",\"revolvingCompensationTimes\":\"0\",\"overdueAccountCount\":\"0\",\"applyTenantCount\":\"0\",\"lendingAmount\":\"0.00\"},\"D90\":{\"accountCount\":\"0\",\"revolvingCompensationCount\":\"0\",\"revolvingCompensationAmount\":\"0.00\",\"creditLimitSum\":\"0.00\",\"revolvingCompensationTimes\":\"0\",\"overdueAccountCount\":\"0\",\"applyTenantCount\":\"0\",\"lendingAmount\":\"0.00\"}},\"financeLease\":{\"D30\":{\"overdueFinLseCount\":\"0\",\"maxFinLseAmount\":\"0.00\",\"finLseTenantCount\":\"0\",\"finLseCompensationCount\":\"0\",\"finLseCount\":\"0\",\"finLseCompensationTimes\":\"0\",\"finLseApplyTenantCount\":\"0\",\"finLseAmount\":\"0.00\",\"averageFinLseAmount\":\"0.00\",\"finLseCompensationAmount\":\"0.00\"},\"summary\":{\"remainingOverdueFinLseCount\":\"0\",\"finLseCurrRemainingOverdueAmount\":\"0.00\",\"finLseCount\":\"0\",\"finLseMaxOverdueStatus\":\"N\",\"openFinLseCount\":\"0\",\"finLseLastCompensationDate\":\"\",\"finLseCurrRemainingMaxOverdueStatus\":\"N\",\"finLseOverdueCount\":\"0\",\"finLseRemainingAmount\":\"0.00\"},\"D360\":{\"overdueFinLseCount\":\"0\",\"maxFinLseAmount\":\"0.00\",\"finLseTenantCount\":\"0\",\"finLseCompensationCount\":\"0\",\"finLseCount\":\"0\",\"finLseCompensationTimes\":\"0\",\"finLseApplyTenantCount\":\"0\",\"finLseAmount\":\"0.00\",\"averageFinLseAmount\":\"0.00\",\"finLseCompensationAmount\":\"0.00\"},\"D180\":{\"overdueFinLseCount\":\"0\",\"maxFinLseAmount\":\"0.00\",\"finLseTenantCount\":\"0\",\"finLseCompensationCount\":\"0\",\"finLseCount\":\"0\",\"finLseCompensationTimes\":\"0\",\"finLseApplyTenantCount\":\"0\",\"finLseAmount\":\"0.00\",\"averageFinLseAmount\":\"0.00\",\"finLseCompensationAmount\":\"0.00\"},\"D90\":{\"overdueFinLseCount\":\"0\",\"maxFinLseAmount\":\"0.00\",\"finLseTenantCount\":\"0\",\"finLseCompensationCount\":\"0\",\"finLseCount\":\"0\",\"finLseCompensationTimes\":\"0\",\"finLseApplyTenantCount\":\"0\",\"finLseAmount\":\"0.00\",\"averageFinLseAmount\":\"0.00\",\"finLseCompensationAmount\":\"0.00\"}},\"nonRevolvingLoan\":{\"D30\":{\"loanTenantCount\":\"0\",\"compensationCount\":\"0\",\"averageLoanAmount\":\"0.00\",\"overdueLoanCount\":\"0\",\"compensationAmount\":\"0.00\",\"loanCount\":\"0\",\"maxLoanAmount\":\"0.00\",\"applyTenantCount\":\"0\",\"loanAmount\":\"0.00\",\"compensationTimes\":\"0\"},\"summary\":{\"lastCompensationDate\":\"\",\"remainingAmount\":\"0.00\",\"remainingOverdueLoanCount\":\"0\",\"remainingOverdueAmount\":\"0.00\",\"remainingMaxOverdueStatus\":\"N\",\"loanCount\":\"0\",\"maxOverdueStatus\":\"N\",\"openLoanCount\":\"0\",\"overdueCount\":\"0\"},\"D360\":{\"loanTenantCount\":\"0\",\"compensationCount\":\"0\",\"averageLoanAmount\":\"0.00\",\"overdueLoanCount\":\"0\",\"compensationAmount\":\"0.00\",\"loanCount\":\"0\",\"maxLoanAmount\":\"0.00\",\"applyTenantCount\":\"1\",\"loanAmount\":\"0.00\",\"compensationTimes\":\"0\"},\"D180\":{\"loanTenantCount\":\"0\",\"compensationCount\":\"0\",\"averageLoanAmount\":\"0.00\",\"overdueLoanCount\":\"0\",\"compensationAmount\":\"0.00\",\"loanCount\":\"0\",\"maxLoanAmount\":\"0.00\",\"applyTenantCount\":\"1\",\"loanAmount\":\"0.00\",\"compensationTimes\":\"0\"},\"D90\":{\"loanTenantCount\":\"0\",\"compensationCount\":\"0\",\"averageLoanAmount\":\"0.00\",\"overdueLoanCount\":\"0\",\"compensationAmount\":\"0.00\",\"loanCount\":\"0\",\"maxLoanAmount\":\"0.00\",\"applyTenantCount\":\"0\",\"loanAmount\":\"0.00\",\"compensationTimes\":\"0\"}},\"objectionLabeling\":[],\"queryHistory\":[{\"date\":\"2023-09-01\",\"tenantType\":\"-\",\"reason\":\"2\",\"tenantName\":\"浙江浙农网络小额贷款有限公司\",\"userId\":\"znwlxd_test_1\"}],\"reportHeader\":{\"reportId\":\"BH2309051543062051830008\",\"queryResult\":\"1\",\"reportTime\":\"2023-09-05T15:43:06\"},\"personalProfile\":{\"idType\":\"1\",\"name\":\"d30b297079aa7503cf593ece9c3a3ee3d4ae19164e4ac11faeeb6f80582b2bda\",\"mobileCount\":\"1\",\"pid\":\"bae37560958f5cb743b4e848d904d8b0ef02739f89f195e02d057d1fdc32d816\"},\"queryTime\":\"2023-10-24 19:20:23\",\"personalStatement\":[],\"homeInfo\":[]},\"HAODUOSHU_CALC_MODEL\":{\"var_detail\":[{\"avg_discount_type_24m_10\":\"0.0\",\"consvariety\":\"-999\",\"hosehold_6m_money\":\"7.5\",\"mobile_buyyear_sumorderamountyear_ydesc_maxlinkratio_yearbuyssumorderamount\":\"-0.3944\",\"mobile_diffPayOrder_desc_ql\":\"6.0\",\"cons_type_cntrate\":\"0.6667\",\"virtual_6m_num\":\"0\",\"diamond_6m_money\":\"0\",\"cnt_type_6m_10\":\"0.0\",\"cnt_type_6m_11\":\"0.0\",\"mobile_diffdays_desc_max\":\"621\",\"cnt_type_6m_13\":\"0.0\",\"mobile_diffPayOrder_desc_qu\":\"44.0\",\"cnt_ttl_6m\":\"2\",\"hosehold_6m_num\":\"1\",\"amt_type_6m_1\":\"0.0\",\"amt_type_6m_5\":\"0.0\",\"amt_type_6m_4\":\"0.0\",\"amt_type_6m_3\":\"0.0\",\"cnt_ttl_12m_Night\":\"0.0\",\"amt_type_6m_2\":\"0.0\",\"amt_ttl_12m_Night\":\"0.0\",\"amt_type_6m_9\":\"0.0\",\"amt_type_6m_8\":\"7.5\",\"amt_type_6m_7\":\"0.0\",\"amt_type_6m_6\":\"0.0\",\"refund_cnt_12m\":\"0.0\",\"type_12m_sum\":\"1\",\"cnt_type_12m_12\":\"0.0\",\"label_24_num\":\"2\",\"cnt_ttl_12m\":\"2\",\"consume_12m_amt\":\"43.0\",\"cnt_type_6m_9\":\"0.0\",\"amt_type_6m_zhineng\":\"0.0\",\"virtual_6m_money\":\"0\",\"mobile_buyyear_meanorderamountyear_ydesc_maxlinkratio_yearbuysmeanorderamount\":\"-0.0915\",\"cnt_type_ratio_6m_10\":\"0.0\",\"cnt_type_ratio_6m_11\":\"0.0\",\"cnt_type_ratio_6m_13\":\"0.0\",\"amt_type_ratio_6m_zhineng\":\"0.0\",\"car_6m_num\":\"0\",\"mobile_diffdays_desc_median\":\"429\",\"mobile_buyyear_sumorderamountyear_ydesc_skew_yearbuyssumorderamount\":\"-999.0\",\"amt_type_36m_13\":\"0.0\",\"mobile_all_cntaddr_desc_fourLevelProv\":\"0\",\"cnt_type_ratio_6m_zhineng\":\"0.0\",\"latest_record_m\":\"2\",\"cons_type_amtrate\":\"0.6512\",\"mobile_buyyear_sumorderamountyear_ydesc_minlinkratio_yearbuyssumorderamount\":\"-0.3944\",\"mobile_all_cntaddr_desc_oneLevelProv\":\"0\",\"sports_6m_money\":\"0\",\"amt_type_ratio_6m_4\":\"0.0\",\"amt_type_ratio_6m_5\":\"0.0\",\"earliest_cons_m\":\"20\",\"amt_type_ratio_6m_2\":\"0.0\",\"amt_type_ratio_6m_3\":\"0.0\",\"cos_stab\":\"0.3023255814\",\"amt_type_ratio_6m_1\":\"0.0\",\"amt_type_ratio_6m_8\":\"0.2113\",\"amt_type_ratio_6m_9\":\"0.0\",\"amt_type_ratio_6m_6\":\"0.0\",\"mon_max_record\":\"28.0\",\"amt_ttl_6m\":\"35.5\",\"amt_type_ratio_6m_7\":\"0.0\",\"level_12m_consume\":\"1\",\"mobile_diffPayOrder_desc_median\":\"6.0\",\"mobile_all_cntaddr_desc_oneLevelCity\":\"0\",\"amt_type_12m_10\":\"0.0\",\"entertainment_6m_money\":\"0\",\"child_6m_money\":\"0\",\"amt_type_12m_12\":\"0.0\",\"mobile_platform_meanAmountcategory_gdesc_max_platformbuysmeanAmount\":\"22.8\",\"diamond_6m_num\":\"0\",\"mobile_buymonth_sumorderamountmonth_mdesc_max_monthbuyssumorderamount\":\"56.0\",\"max_interval_month\":\"10\",\"amt_type_6m_10\":\"0.0\",\"amt_type_6m_11\":\"0.0\",\"amt_type_6m_13\":\"0.0\",\"child_6m_num\":\"0\",\"cnt_type_36m_9\":\"0.0\",\"mobile_all_cntaddr_desc_threeLevelCity\":\"0\",\"sports_6m_num\":\"0\",\"cnt_type_6m_zhineng\":\"0.0\",\"discount_cnt_12m\":\"1\",\"cnt_type_6m_4\":\"0.0\",\"close_12m_mean_money\":\"0\",\"mobile_diffdays_desc_drange\":\"557\",\"cnt_type_6m_3\":\"0.0\",\"cnt_type_6m_2\":\"0.0\",\"cnt_type_6m_1\":\"0.0\",\"amt_ttl_12m\":\"43.0\",\"cnt_type_6m_8\":\"1\",\"div_cons_24m\":\"0.6964\",\"cnt_type_6m_7\":\"0.0\",\"cnt_type_6m_6\":\"0.0\",\"mobile_email_desc_emailIsTrue\":\"0\",\"cnt_type_6m_5\":\"0.0\",\"car_6m_money\":\"0\",\"month_num\":\"2\",\"amt_type_ratio_6m_13\":\"0.0\",\"consume_12m_cnt\":\"2\",\"digital_6m_num\":\"0\",\"amt_type_ratio_6m_11\":\"0.0\",\"amt_type_ratio_6m_10\":\"0.0\",\"avg_amt_type_36m_4\":\"0.0\",\"cnt_type_ratio_6m_1\":\"0.0\",\"cnt_type_ratio_6m_2\":\"0.0\",\"cnt_type_ratio_6m_3\":\"0.0\",\"cnt_type_ratio_6m_4\":\"0.0\",\"mobile\":\"15325811208\",\"amt_type_24m_11\":\"0.0\",\"entertainment_6m_num\":\"0\",\"digital_6m_money\":\"0\",\"mobile_diffPayOrder_desc_mean\":\"21.0\",\"cnt_type_ratio_6m_9\":\"0.0\",\"cnt_type_ratio_6m_5\":\"0.0\",\"cnt_type_ratio_6m_6\":\"0.0\",\"cnt_type_ratio_6m_7\":\"0.0\",\"cnt_type_ratio_6m_8\":\"0.5\"}],\"code_message\":\"successful result\",\"code\":\"200\",\"queryTime\":\"2023-10-24 19:20:24\",\"reqTime\":\"2023-03-02 16:52:13\"},\"PD_YS_ZHONGHE_V2\":{\"flag\":\"1\",\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"psce_integrate_trans1\":\"294\",\"decode_score_z3\":\"731\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022981504\",\"comprs\":\"0\"},\"RONG360_LHZXV1_SCORE\":{\"tianji_api_agentzj_loanscore_response\":{\"score\":\"0.0182\"},\"queryTime\":\"2023-10-24 19:20:24\",\"error\":\"200\",\"request_id\":\"16981461558215875817\"},\"BAIRONG_QUANTILE\":{\"code\":\"100002\",\"swift_number\":\"3031389_20231024192023_6957\",\"queryTime\":\"2023-10-24 19:20:23\",\"message\":\"未预埋数据,请联系对接的交付人员\"},\"BAIRONG_PORTRAYAL_2\":{\"code\":\"100002\",\"swift_number\":\"3031389_20231024192024_6959\",\"queryTime\":\"2023-10-24 19:20:24\",\"message\":\"未预埋数据,请联系对接的交付人员\"},\"TALKINGDATA_SCORE\":{\"msg\":\"请求成功\",\"code\":\"2001\",\"data\":{\"credit_17\":\"539\"},\"queryTime\":\"2023-10-24 19:20:23\",\"seq\":\"e4c074dced6541458c6b2c575b35784a\"},\"PD_XYS_XYSL\":{\"flag\":\"1\",\"data\":{\"creditScore\":\"520.483\",\"orderId\":\"10435820221207173101\",\"searchType\":\"3\",\"authFlag\":\"1\",\"scUsePurpose\":\"ceshi\",\"scName\":\"ceshi\",\"instId\":\"999920220420001\",\"encryption\":\"1\",\"merNo\":\"737222206168001\",\"respMsg\":\"认证/查询成功\",\"busiType\":\"1637\",\"scUsageScenarios\":\"ceshi\",\"merResv\":\"737222206168001|999920220420001\",\"orderDate\":\"20221207\",\"respCode\":\"00000000\"},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:24\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022151596\",\"comprs\":\"0\"},\"HAODUOSHU_STOCK\":{\"msg\":\"OK\",\"errorType\":\"0\",\"queryTime\":\"2023-10-24 19:20:23\",\"content\":{\"applyAmountIntervalRecent60\":\"0\",\"earlyApplyTimeRecent180\":\"2023-05-10 18:17:06\",\"earlyApprovalTimeRecent180\":\"\",\"applyCount\":\"242\",\"applyCountRecent30\":\"0\",\"earlyApprovalTimeRecent30\":\"\",\"applyPlatFormCount\":\"1\",\"recentApplyTimeRecent90\":\"2023-08-09 14:08:23\",\"applyPlatFormCountRecent60\":\"0\",\"recentApplyTimeRecent180\":\"2023-08-09 14:08:23\",\"approvalCount\":\"0\",\"earlyApprovalTime\":\"\",\"earlyApplyTime\":\"2023-03-14 11:16:21\",\"approvalPlatFormCountRecent3\":\"0\",\"earlyApplyTimeRecent90\":\"2023-07-26 19:47:35\",\"approvalAmountIntervalRecent90\":\"0\",\"applyCountRecent180\":\"113\",\"earlyApprovalTimeRecent7\":\"\",\"applyAmountIntervalRecent30\":\"0\",\"recentApprovalTimeRecent180\":\"\",\"approvalPlatFormCountRecent30\":\"0\",\"applyAmountIntervalRecent7\":\"0\",\"approvalCountRecent180\":\"0\",\"recentApplyTimeRecent60\":\"\",\"applyPlatFormCountRecent180\":\"0\",\"applyPlatFormCountRecent90\":\"0\",\"approvalAmountIntervalRecent180\":\"0\",\"earlyApprovalTimeRecent3\":\"\",\"approvalCountRecent90\":\"0\",\"applyCountRecent7\":\"0\",\"applyAmountIntervalRecent3\":\"0\",\"recentApprovalTimeRecent60\":\"\",\"applyCountRecent3\":\"0\",\"earlyApplyTimeRecent60\":\"\",\"approvalPlatFormCountRecent180\":\"0\",\"recentApprovalTimeRecent3\":\"\",\"earlyApplyTimeRecent30\":\"\",\"earlyApprovalTimeRecent90\":\"\",\"recentApplyTimeRecent30\":\"\",\"applyAmountInterval\":\"148\",\"approvalCountRecent30\":\"0\",\"approvalPlatFormCount\":\"0\",\"applyCountRecent90\":\"69\",\"approvalAmountIntervalRecent30\":\"0\",\"recentApplyTimeRecent3\":\"\",\"recentApprovalTimeRecent30\":\"\",\"recentApplyTimeRecent7\":\"\",\"approvalPlatFormCountRecent60\":\"0\",\"approvalAmountIntervalRecent7\":\"0\",\"approvalAmountInterval\":\"0\",\"approvalAmountIntervalRecent3\":\"0\",\"applyAmountIntervalRecent90\":\"14\",\"recentApprovalTimeRecent7\":\"\",\"applyPlatFormCountRecent7\":\"0\",\"applyPlatFormCountRecent3\":\"0\",\"approvalCountRecent3\":\"0\",\"applyCountRecent60\":\"0\",\"earlyApplyTimeRecent7\":\"\",\"approvalPlatFormCountRecent7\":\"0\",\"recentApprovalTimeRecent90\":\"\",\"applyPlatFormCountRecent30\":\"0\",\"earlyApprovalTimeRecent60\":\"\",\"applyAmountIntervalRecent180\":\"91\",\"approvalCountRecent60\":\"0\",\"earlyApplyTimeRecent3\":\"\",\"recentApprovalTime\":\"\",\"approvalPlatFormCountRecent90\":\"0\",\"approvalCountRecent7\":\"0\",\"approvalAmountIntervalRecent60\":\"0\",\"recentApplyTime\":\"2023-08-09 14:08:23\"}},\"RONG360_ZXFV3_SCORE\":{\"flag\":\"1\",\"data\":{\"tianji_api_pudao_getResult_response\":{\"riskScore\":\"659\"},\"error\":\"200\",\"request_id\":\"16920864002270566160\"},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:26\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022440661\",\"unif_mult_label_score_ex_v1.0_s1848\":{\"flag\":\"1\",\"resp_cd\":\"000000\",\"resp_msg\":\"处理成功\"},\"comprs\":\"0\"},\"PD_TONGDUN\":{\"flag\":\"1\",\"data\":{\"success\":true,\"result_desc\":{\"INFOANALYSIS\":{\"id_age\":\"23\",\"address_detect\":{\"mobile_address_city\":\"杭州市\",\"id_card_city\":\"龙岩市\",\"mobile_address\":\"浙江省杭州市\",\"id_card_province\":\"福建省\",\"mobile_address_province\":\"浙江省\",\"id_card_address\":\"福建省龙岩市上杭县\"},\"geoip_info\":{},\"device_info\":{\"error\":\"参数缺失\"},\"geotrueip_info\":{},\"id_gender\":\"M\"},\"ANTIFRAUD\":{\"final_score\":\"0\",\"risk_items\":[{\"rule_id\":\"70338504\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"100\",\"policy_decision\":\"100\",\"policy_name\":\"申请行为异常_网站\",\"risk_name\":\"设备ID缺失\"},{\"rule_id\":\"70338404\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"7天内申请人申请次数_身份证维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"7天内申请人身份证号申请借款次数\",\"dim_type\":\"idNumber\",\"count\":\"1\",\"detail\":\"7天内申请人身份证号申请借款次数：1\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338414\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"1月内申请人申请次数_身份证维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"1月内申请人身份证号申请借款次数\",\"dim_type\":\"idNumber\",\"count\":\"1\",\"detail\":\"1月内申请人身份证号申请借款次数：1\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338424\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"3月内申请人申请次数_身份证维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"3月内申请人身份证号申请借款次数\",\"dim_type\":\"idNumber\",\"count\":\"1\",\"detail\":\"3月内申请人身份证号申请借款次数：1\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338434\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"6月内申请人申请次数_身份证维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"6月内申请人身份证号申请借款次数\",\"dim_type\":\"idNumber\",\"count\":\"1\",\"detail\":\"6月内申请人身份证号申请借款次数：1\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338444\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"7天内申请人申请次数_手机号维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"7天内申请人手机号申请借款次数\",\"dim_type\":\"accountMobile\",\"count\":\"2\",\"detail\":\"7天内申请人手机号申请借款次数：2\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338454\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"1月内申请人申请次数_手机号维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"1月内申请人手机号申请借款次数\",\"dim_type\":\"accountMobile\",\"count\":\"2\",\"detail\":\"1月内申请人手机号申请借款次数：2\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338464\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"3月内申请人申请次数_手机号维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"3月内申请人手机号申请借款次数\",\"dim_type\":\"accountMobile\",\"count\":\"690\",\"detail\":\"3月内申请人手机号申请借款次数：690\"}],\"type\":\"frequency_detail\"}]},{\"rule_id\":\"70338474\",\"policy_score\":\"0\",\"score\":\"0\",\"policy_mode\":\"Weighted\",\"decision\":\"\",\"policy_decision\":\"100\",\"policy_name\":\"异常借款_网站\",\"risk_name\":\"6月内申请人申请次数_手机号维度\",\"risk_detail\":[{\"frequency_detail_list\":[{\"note\":\"6月内申请人手机号申请借款次数\",\"dim_type\":\"accountMobile\",\"count\":\"690\",\"detail\":\"6月内申请人手机号申请借款次数：690\"}],\"type\":\"frequency_detail\"}]}],\"final_decision\":\"100\"}},\"id\":\"WF2023102419202733407061\"},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:27\",\"daiqianshenhe_t1\":{\"flag\":\"1\",\"resp_cd\":\"000000\",\"resp_msg\":\"处理成功\"},\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022591540\",\"comprs\":\"0\"},\"HAODUOSHU_SCORE\":{\"msg\":\"OK\",\"errorType\":\"0\",\"queryTime\":\"2023-10-24 19:20:23\",\"content\":{\"rankConsume_act2\":\"B\",\"rankPerformanceCapability\":\"B\",\"rankConsume_act1\":\"A\",\"rankConsume_cap\":\"C\",\"score\":\"493\",\"rankBehavioral\":\"B\",\"rankIdentityTrait\":\"A\"}},\"HAODUOSHU_LOGISTICS\":{\"msg\":\"OK\",\"errorType\":\"0\",\"queryTime\":\"2023-10-24 19:20:25\",\"content\":{\"addrCount\":\"1\",\"recent30Count\":\"0\",\"expCityCount\":\"1\",\"recent90Count\":\"0\",\"freAddrCityLel\":\"1\",\"recent720Count\":\"2\",\"freAddrCount\":\"3\",\"recent360Count\":\"0\",\"recent180Count\":\"0\",\"expCount\":\"1\",\"recent90RejCount\":\"0\",\"recent180RejCount\":\"0\",\"retGoodsRate\":\"0\",\"postageRate\":\"1\",\"recent360RejCount\":\"0\"}},\"PD_YS_DUOTOU_V2\":{\"flag\":\"1\",\"decode_score_x3\":\"738\",\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:23\",\"psce_integrate_trans2\":\"211\",\"resp_msg\":\"处理成功\",\"rqst_id\":\"20231024192022688466\",\"comprs\":\"0\"},\"TIANCHUANG_ONLINETIME_V2\":{\"data\":{\"result\":\"0\",\"isFee\":\"1\",\"province\":\"江西\",\"city\":\"宜春\",\"isp\":\"移动\",\"resultMsg\":\"[0,3)\"},\"seqNum\":\"63387af4923e4bc4b1e74c2ddce6f30b\",\"queryTime\":\"2023-10-24 19:20:24\",\"message\":\"成功\",\"status\":\"0\"},\"BAIRONG_APPLYLOANSTR_V2\":{\"als_m1_cell_nbank_p2p_orgnum\":\"1\",\"als_m1_cell_nbank_allnum\":\"14\",\"als_d15_cell_nbank_week_allnum\":\"0\",\"als_m1_id_bank_ret_allnum\":\"1\",\"als_d7_id_nbank_night_allnum\":\"0\",\"als_m12_cell_nbank_nsloan_orgnum\":\"7\",\"als_d15_id_nbank_ca_allnum\":\"1\",\"als_m6_id_bank_tra_allnum\":\"6\",\"als_d7_cell_caoff_orgnum\":\"2\",\"als_m6_cell_nbank_max_inteday\":\"14\",\"als_m12_id_bank_selfnum\":\"0\",\"als_m12_cell_nbank_ca_allnum\":\"8\",\"als_m6_cell_nbank_else_allnum\":\"5\",\"als_d15_id_nbank_else_orgnum\":\"3\",\"als_m6_id_pdl_allnum\":\"19\",\"als_d7_cell_nbank_allnum\":\"7\",\"als_m3_cell_min_monnum\":\"5\",\"als_d15_id_pdl_allnum\":\"2\",\"als_d15_cell_pdl_orgnum\":\"2\",\"als_d7_id_nbank_else_orgnum\":\"3\",\"als_m1_cell_caoff_orgnum\":\"2\",\"als_m3_id_bank_tra_allnum\":\"3\",\"als_m6_cell_nbank_orgnum\":\"24\",\"als_m1_cell_nbank_oth_allnum\":\"9\",\"als_d15_id_nbank_nsloan_orgnum\":\"4\",\"als_m12_cell_bank_ret_orgnum\":\"2\",\"als_m12_id_bank_min_monnum\":\"0\",\"als_d7_id_nbank_ca_allnum\":\"1\",\"als_m12_id_bank_allnum\":\"15\",\"als_m1_id_caoff_orgnum\":\"2\",\"als_d15_id_rel_orgnum\":\"2\",\"als_m1_cell_nbank_oth_orgnum\":\"9\",\"als_d15_id_cooff_orgnum\":\"1\",\"als_m12_cell_nbank_sloan_orgnum\":\"2\",\"als_m1_id_nbank_allnum\":\"18\",\"als_m6_cell_nbank_max_monnum\":\"15\",\"als_m12_cell_caon_allnum\":\"30\",\"als_m6_cell_nbank_night_allnum\":\"8\",\"flag_score\":\"1\",\"als_d15_cell_caon_allnum\":\"6\",\"als_m3_cell_nbank_orgnum\":\"20\",\"als_m3_cell_nbank_finlea_allnum\":\"1\",\"als_d15_cell_nbank_finlea_allnum\":\"1\",\"als_m3_cell_min_inteday\":\"0\",\"als_m6_cell_nbank_sloan_allnum\":\"4\",\"als_m1_id_nbank_ca_allnum\":\"1\",\"als_m3_id_nbank_p2p_allnum\":\"1\",\"als_m12_id_nbank_max_monnum\":\"19\",\"als_m1_id_nbank_finlea_allnum\":\"1\",\"als_m1_cell_nbank_sloan_allnum\":\"1\",\"als_m3_id_min_inteday\":\"0\",\"als_m6_cell_nbank_p2p_allnum\":\"1\",\"als_m12_cell_bank_orgnum\":\"8\",\"als_m1_cell_nbank_night_orgnum\":\"0\",\"als_m12_cell_oth_orgnum\":\"1\",\"als_d7_cell_caoff_allnum\":\"2\",\"als_m1_id_nbank_cf_orgnum\":\"4\",\"als_d7_cell_nbank_oth_orgnum\":\"5\",\"als_m6_cell_bank_tra_allnum\":\"5\",\"als_lst_cell_bank_csinteday\":\"1\",\"als_d15_cell_nbank_night_orgnum\":\"0\",\"als_m6_cell_nbank_night_orgnum\":\"7\",\"als_m12_cell_nbank_nsloan_allnum\":\"19\",\"als_m12_cell_oth_allnum\":\"1\",\"als_m12_cell_nbank_max_inteday\":\"50\",\"als_m6_cell_max_monnum\":\"16\",\"rs_product_name\":\"预置_打包1\",\"als_d15_cell_nbank_night_allnum\":\"0\",\"als_m12_cell_min_monnum\":\"1\",\"als_m12_cell_bank_allnum\":\"13\",\"als_m3_id_nbank_max_monnum\":\"19\",\"als_m3_cell_max_monnum\":\"16\",\"als_m1_id_coon_orgnum\":\"1\",\"als_m3_id_bank_min_monnum\":\"0\",\"als_d7_id_nbank_night_orgnum\":\"0\",\"als_m6_cell_bank_tra_orgnum\":\"4\",\"als_m1_cell_nbank_night_allnum\":\"0\",\"als_m3_cell_nbank_allnum\":\"29\",\"als_m12_id_nbank_p2p_allnum\":\"1\",\"als_m3_id_bank_tra_orgnum\":\"3\",\"als_m1_cell_caoff_allnum\":\"2\",\"als_d7_cell_nbank_orgnum\":\"7\",\"als_d15_id_nbank_else_allnum\":\"3\",\"als_d15_cell_nbank_cf_allnum\":\"1\",\"als_m1_id_coon_allnum\":\"1\",\"als_m6_cell_nbank_oth_allnum\":\"25\",\"als_m6_cell_nbank_selfnum\":\"0\",\"als_d15_cell_coon_allnum\":\"1\",\"als_m12_cell_nbank_sloan_allnum\":\"7\",\"als_m1_id_nbank_ca_orgnum\":\"1\",\"als_m12_cell_coon_allnum\":\"2\",\"als_m12_id_nbank_cons_orgnum\":\"12\",\"als_m3_cell_bank_max_monnum\":\"3\",\"als_m12_cell_nbank_night_orgnum\":\"7\",\"als_m6_id_nbank_nsloan_allnum\":\"24\",\"als_m3_id_nbank_oth_allnum\":\"23\",\"als_m12_id_bank_orgnum\":\"10\",\"als_d15_cell_nbank_else_orgnum\":\"3\",\"als_m3_id_nbank_p2p_orgnum\":\"1\",\"swift_number\":\"3031772_20230117100200_5175096EA19\",\"als_m6_cell_nbank_finlea_allnum\":\"1\",\"als_m12_id_tot_mons\":\"12\",\"rs_product_type\":\"100081\",\"als_m12_id_avg_monnum\":\"7.50\",\"als_m12_cell_nbank_else_allnum\":\"5\",\"rs_Rule_decision\":\"Reject\",\"als_m3_id_nbank_sloan_orgnum\":\"1\",\"als_m3_cell_nbank_max_inteday\":\"13\",\"als_d15_cell_pdl_allnum\":\"2\",\"als_m1_cell_nbank_p2p_allnum\":\"1\",\"als_m1_id_nbank_orgnum\":\"17\",\"als_m3_id_bank_selfnum\":\"0\",\"als_d15_id_nbank_ca_orgnum\":\"1\",\"als_m6_id_bank_tra_orgnum\":\"5\",\"flag_ruleapplyloan\":\"1\",\"als_m1_cell_nbank_orgnum\":\"14\",\"als_m6_id_bank_selfnum\":\"0\",\"als_m6_id_max_monnum\":\"21\",\"als_m12_cell_bank_selfnum\":\"0\",\"als_d15_cell_nbank_else_allnum\":\"3\",\"als_m3_cell_nbank_selfnum\":\"0\",\"als_m6_id_nbank_else_orgnum\":\"5\",\"als_m3_id_nbank_oth_orgnum\":\"15\",\"als_m12_id_nbank_ca_allnum\":\"34\",\"als_m1_cell_nbank_cons_allnum\":\"6\",\"als_d7_id_nbank_else_allnum\":\"3\",\"als_m3_id_nbank_max_inteday\":\"10\",\"als_d15_id_nbank_selfnum\":\"0\",\"als_m12_cell_nbank_max_monnum\":\"15\",\"als_m6_cell_min_monnum\":\"2\",\"als_m6_id_bank_avg_monnum\":\"2.00\",\"als_m12_id_nbank_selfnum\":\"0\",\"als_m12_cell_bank_ret_allnum\":\"3\",\"als_m1_id_caoff_allnum\":\"2\",\"als_m6_cell_nbank_oth_orgnum\":\"14\",\"als_m1_cell_nbank_cons_orgnum\":\"6\",\"als_m6_id_pdl_orgnum\":\"7\",\"als_lst_id_nbank_consnum\":\"1\",\"als_m6_id_rel_allnum\":\"14\",\"als_m6_id_rel_orgnum\":\"6\",\"als_m12_id_nbank_oth_allnum\":\"35\",\"als_m12_id_cooff_orgnum\":\"3\",\"als_m6_cell_tot_mons\":\"6\",\"als_m12_id_bank_tra_allnum\":\"11\",\"als_m12_id_nbank_ca_orgnum\":\"4\",\"als_m3_id_max_inteday\":\"10\",\"als_m6_id_nbank_else_allnum\":\"6\",\"als_d7_id_nbank_selfnum\":\"0\",\"als_m3_id_nbank_else_orgnum\":\"4\",\"als_m3_cell_nbank_sloan_orgnum\":\"1\",\"als_m1_id_nbank_night_orgnum\":\"2\",\"als_m12_id_bank_tra_orgnum\":\"7\",\"als_m6_cell_nbank_nsloan_allnum\":\"15\",\"als_m6_cell_pdl_allnum\":\"17\",\"als_m12_id_bank_ret_allnum\":\"4\",\"als_m1_id_bank_orgnum\":\"2\",\"als_m3_cell_pdl_allnum\":\"9\",\"als_m1_id_bank_selfnum\":\"0\",\"als_m12_cell_nbank_cf_allnum\":\"28\",\"als_d7_id_nbank_week_orgnum\":\"0\",\"als_d15_cell_nbank_nsloan_allnum\":\"2\",\"als_m3_id_rel_orgnum\":\"6\",\"Rule_name_QJF079\":\"在银行机构申请次数较多\",\"als_m3_cell_nbank_nsloan_orgnum\":\"5\",\"als_m6_id_nbank_min_inteday\":\"0\",\"Rule_name_QJF077\":\"在非银机构申请次数较多\",\"Rule_name_QJF078\":\"在银行机构申请次数极多\",\"als_d7_id_nbank_cons_allnum\":\"1\",\"als_m1_id_nbank_nsloan_orgnum\":\"5\",\"als_m3_id_coon_allnum\":\"2\",\"Rule_name_QJF076\":\"在非银机构申请次数极多\",\"als_m3_id_nbank_ca_orgnum\":\"3\",\"als_m3_id_caon_orgnum\":\"15\",\"als_m6_id_nbank_nsloan_orgnum\":\"9\",\"als_m6_cell_nbank_cons_allnum\":\"25\",\"als_d7_id_nbank_cons_orgnum\":\"1\",\"als_d7_id_nbank_nsloan_allnum\":\"2\",\"als_m1_cell_nbank_week_allnum\":\"0\",\"als_m12_cell_nbank_else_orgnum\":\"4\",\"als_m1_id_nbank_sloan_allnum\":\"1\",\"als_m1_id_nbank_nsloan_allnum\":\"6\",\"als_d7_cell_nbank_oth_allnum\":\"5\",\"als_d7_cell_nbank_else_orgnum\":\"3\",\"als_m3_cell_nbank_nsloan_allnum\":\"6\",\"als_d15_id_bank_night_allnum\":\"0\",\"als_d15_id_bank_allnum\":\"1\",\"als_m1_id_nbank_cf_allnum\":\"4\",\"als_lst_cell_nbank_inteday\":\"1\",\"als_m1_cell_bank_week_orgnum\":\"0\",\"als_m3_id_nbank_ca_allnum\":\"3\",\"als_m3_id_coon_orgnum\":\"1\",\"als_m3_cell_bank_week_allnum\":\"0\",\"als_lst_id_bank_inteday\":\"12\",\"als_m6_id_max_inteday\":\"16\",\"als_m12_id_nbank_p2p_orgnum\":\"1\",\"als_m12_cell_rel_orgnum\":\"5\",\"als_m1_id_bank_allnum\":\"2\",\"als_m6_id_bank_ret_orgnum\":\"3\",\"als_m12_cell_nbank_min_monnum\":\"0\",\"als_m6_id_tot_mons\":\"6\",\"als_m1_id_bank_week_allnum\":\"0\",\"als_m12_cell_bank_max_monnum\":\"3\",\"als_m6_cell_nbank_finlea_orgnum\":\"1\",\"als_m3_cell_tot_mons\":\"3\",\"als_m12_id_rel_allnum\":\"20\",\"als_d7_id_nbank_nsloan_orgnum\":\"2\",\"als_m3_id_bank_max_inteday\":\"52\",\"als_m3_id_rel_allnum\":\"11\",\"als_m12_cell_nbank_selfnum\":\"0\",\"als_m3_cell_bank_week_orgnum\":\"0\",\"als_d15_cell_nbank_finlea_orgnum\":\"1\",\"als_m12_cell_tot_mons\":\"12\",\"als_m3_id_nbank_else_allnum\":\"4\",\"als_d15_id_nbank_cons_orgnum\":\"5\",\"als_m1_cell_bank_week_allnum\":\"0\",\"als_m1_id_nbank_finlea_orgnum\":\"1\",\"als_m3_cell_nbank_else_orgnum\":\"4\",\"als_m12_id_rel_orgnum\":\"6\",\"als_lst_cell_bank_inteday\":\"29\",\"als_m6_cell_nbank_ca_orgnum\":\"3\",\"als_m6_id_nbank_min_monnum\":\"0\",\"als_d15_cell_coon_orgnum\":\"1\",\"als_d15_id_bank_night_orgnum\":\"0\",\"als_m3_cell_nbank_else_allnum\":\"4\",\"als_m12_id_bank_max_inteday\":\"66\",\"als_m6_id_bank_min_monnum\":\"0\",\"als_m3_id_nbank_tot_mons\":\"3\",\"rs_strategy_id\":\"STR_BR0004755\",\"als_m3_id_bank_orgnum\":\"4\",\"als_m3_id_bank_week_allnum\":\"0\",\"als_m3_cell_nbank_night_orgnum\":\"4\",\"als_m6_cell_nbank_sloan_orgnum\":\"2\",\"als_m3_cell_nbank_ca_allnum\":\"2\",\"als_m3_cell_nbank_finlea_orgnum\":\"1\",\"als_m1_cell_cooff_allnum\":\"1\",\"als_d15_id_nbank_cons_allnum\":\"5\",\"als_d7_cell_nbank_p2p_orgnum\":\"1\",\"als_m1_id_nbank_sloan_orgnum\":\"1\",\"als_m3_cell_nbank_p2p_allnum\":\"1\",\"als_m1_cell_bank_allnum\":\"1\",\"als_m1_id_rel_allnum\":\"4\",\"als_m12_cell_max_monnum\":\"16\",\"als_m12_cell_nbank_allnum\":\"64\",\"als_d15_id_cooff_allnum\":\"1\",\"als_m1_cell_bank_night_allnum\":\"0\",\"als_d15_id_nbank_week_orgnum\":\"0\",\"als_d7_id_nbank_week_allnum\":\"0\",\"als_m1_id_nbank_night_allnum\":\"2\",\"als_m12_cell_rel_allnum\":\"16\",\"als_lst_id_bank_csinteday\":\"1\",\"als_m1_id_bank_week_orgnum\":\"0\",\"als_d15_id_nbank_p2p_orgnum\":\"1\",\"Rule_weight_QJF078\":\"30\",\"Rule_weight_QJF079\":\"20\",\"Rule_weight_QJF076\":\"80\",\"als_m12_id_nbank_else_orgnum\":\"5\",\"Rule_weight_QJF077\":\"60\",\"als_m3_id_bank_tot_mons\":\"2\",\"rs_Rule_weight\":\"80\",\"als_m12_cell_bank_tra_allnum\":\"10\",\"als_m3_id_bank_max_monnum\":\"3\",\"als_m1_id_cooff_allnum\":\"2\",\"als_m3_id_nbank_selfnum\":\"0\",\"als_m1_cell_nbank_week_orgnum\":\"0\",\"als_d15_id_nbank_sloan_allnum\":\"1\",\"als_m3_cell_pdl_orgnum\":\"3\",\"als_d15_id_nbank_sloan_orgnum\":\"1\",\"als_m6_cell_nbank_allnum\":\"50\",\"als_m3_cell_nbank_cf_allnum\":\"9\",\"als_m1_id_nbank_week_allnum\":\"0\",\"als_m6_cell_pdl_orgnum\":\"5\",\"als_m12_cell_bank_tra_orgnum\":\"6\",\"als_d15_id_rel_allnum\":\"2\",\"als_m6_id_bank_tot_mons\":\"5\",\"als_m3_id_tot_mons\":\"3\",\"als_d15_cell_caon_orgnum\":\"6\",\"als_m6_cell_nbank_nsloan_orgnum\":\"7\",\"als_d15_id_nbank_oth_allnum\":\"9\",\"als_d7_cell_nbank_else_allnum\":\"3\",\"als_m12_id_bank_week_allnum\":\"3\",\"als_lst_id_nbank_inteday\":\"1\",\"als_m6_id_nbank_selfnum\":\"0\",\"als_m6_id_min_monnum\":\"2\",\"code\":\"00\",\"als_d15_id_nbank_p2p_allnum\":\"1\",\"als_m12_id_caoff_allnum\":\"6\",\"als_m12_cell_nbank_ca_orgnum\":\"3\",\"als_d15_id_bank_selfnum\":\"0\",\"als_m3_cell_bank_tra_orgnum\":\"2\",\"als_d15_cell_nbank_nsloan_orgnum\":\"2\",\"als_m6_cell_nbank_else_orgnum\":\"4\",\"als_d15_id_nbank_week_allnum\":\"0\",\"als_fst_id_bank_inteday\":\"321\",\"als_m3_cell_caoff_allnum\":\"3\",\"als_m3_id_avg_monnum\":\"14.00\",\"als_d15_id_nbank_night_orgnum\":\"0\",\"als_m1_cell_bank_selfnum\":\"0\",\"als_m3_cell_nbank_night_allnum\":\"5\",\"als_d15_id_nbank_night_allnum\":\"0\",\"als_m12_cell_nbank_orgnum\":\"25\",\"als_m3_cell_nbank_ca_orgnum\":\"2\",\"als_m3_cell_nbank_sloan_allnum\":\"2\",\"als_d7_cell_nbank_night_allnum\":\"0\",\"als_lst_id_nbank_csinteday\":\"1\",\"als_m3_id_bank_week_orgnum\":\"0\",\"als_m12_id_caoff_orgnum\":\"3\",\"als_m12_cell_nbank_avg_monnum\":\"5.82\",\"als_m3_id_nbank_allnum\":\"38\",\"als_m3_cell_bank_tra_allnum\":\"2\",\"als_m1_cell_bank_night_orgnum\":\"0\",\"als_m12_id_bank_ret_orgnum\":\"3\",\"als_m6_id_nbank_allnum\":\"61\",\"als_m12_cell_nbank_cf_orgnum\":\"7\",\"als_m6_cell_nbank_min_monnum\":\"0\",\"als_m1_cell_bank_orgnum\":\"1\",\"als_d7_cell_nbank_p2p_allnum\":\"1\",\"als_d7_cell_nbank_night_orgnum\":\"0\",\"als_m3_cell_caoff_orgnum\":\"3\",\"als_d15_id_coon_allnum\":\"1\",\"als_m12_id_max_monnum\":\"21\",\"als_d7_id_caoff_orgnum\":\"2\",\"als_m12_cell_bank_week_allnum\":\"3\",\"als_m6_id_coon_allnum\":\"2\",\"als_d15_id_nbank_allnum\":\"14\",\"als_m12_cell_bank_min_inteday\":\"0\",\"als_m12_cell_bank_night_orgnum\":\"0\",\"als_d7_id_nbank_oth_orgnum\":\"5\",\"als_m1_id_pdl_allnum\":\"2\",\"als_m12_id_min_monnum\":\"1\",\"als_d7_cell_nbank_ca_orgnum\":\"1\",\"als_m12_id_bank_week_orgnum\":\"1\",\"als_m1_id_bank_night_allnum\":\"0\",\"als_m3_id_max_monnum\":\"21\",\"als_m3_cell_nbank_oth_orgnum\":\"13\",\"als_m12_cell_min_inteday\":\"0\",\"als_d7_cell_nbank_selfnum\":\"0\",\"als_d15_cell_nbank_selfnum\":\"0\",\"als_d7_cell_nbank_finlea_allnum\":\"1\",\"als_m3_id_nbank_orgnum\":\"24\",\"als_m3_cell_bank_max_inteday\":\"52\",\"als_lst_id_bank_consnum\":\"1\",\"als_d15_id_caon_orgnum\":\"7\",\"als_m6_cell_bank_ret_allnum\":\"3\",\"als_m1_id_nbank_week_orgnum\":\"0\",\"als_m6_id_nbank_orgnum\":\"28\",\"als_m1_id_nbank_cons_allnum\":\"6\",\"als_fst_cell_bank_inteday\":\"321\",\"als_m6_cell_coon_orgnum\":\"1\",\"als_m6_id_avg_monnum\":\"11.83\",\"als_m3_cell_nbank_cons_orgnum\":\"9\",\"als_d7_id_coon_orgnum\":\"1\",\"als_m3_id_bank_night_allnum\":\"0\",\"als_d15_id_caoff_orgnum\":\"2\",\"als_m3_cell_nbank_p2p_orgnum\":\"1\",\"als_d7_id_nbank_p2p_orgnum\":\"1\",\"als_m6_cell_bank_week_orgnum\":\"1\",\"als_m3_cell_bank_night_orgnum\":\"0\",\"als_m12_id_nbank_else_allnum\":\"6\",\"als_m1_cell_cooff_orgnum\":\"1\",\"als_m3_cell_nbank_cf_orgnum\":\"4\",\"als_m6_id_bank_night_orgnum\":\"0\",\"als_m3_id_nbank_cons_orgnum\":\"10\",\"als_m6_id_nbank_finlea_allnum\":\"1\",\"als_m1_id_bank_tra_orgnum\":\"1\",\"als_m1_id_cooff_orgnum\":\"2\",\"als_d15_cell_nbank_ca_orgnum\":\"1\",\"als_fst_id_nbank_inteday\":\"342\",\"als_m1_cell_nbank_else_allnum\":\"4\",\"als_m1_cell_nbank_cf_allnum\":\"3\",\"als_d15_id_nbank_oth_orgnum\":\"9\",\"als_m12_id_nbank_night_allnum\":\"10\",\"als_m3_cell_caon_orgnum\":\"12\",\"als_d7_cell_nbank_cons_orgnum\":\"1\",\"als_m12_id_nbank_avg_monnum\":\"6.82\",\"als_d15_cell_nbank_orgnum\":\"11\",\"als_m1_id_nbank_cons_orgnum\":\"6\",\"als_d7_id_caon_orgnum\":\"4\",\"als_m12_id_nbank_cf_allnum\":\"30\",\"als_m1_id_pdl_orgnum\":\"2\",\"als_m12_cell_bank_tot_mons\":\"9\",\"als_m12_id_nbank_sloan_allnum\":\"7\",\"als_m3_cell_nbank_oth_allnum\":\"17\",\"als_m6_id_nbank_oth_allnum\":\"33\",\"als_m6_id_bank_ret_allnum\":\"4\",\"als_m3_id_nbank_cons_allnum\":\"17\",\"als_m12_cell_nbank_cons_orgnum\":\"11\",\"als_m3_id_nbank_cf_allnum\":\"11\",\"als_m12_cell_bank_avg_monnum\":\"1.44\",\"als_m3_cell_bank_night_allnum\":\"0\",\"als_m6_cell_nbank_avg_monnum\":\"10.00\",\"flag_rulespeciallist_c\":\"0\",\"als_d15_id_coon_orgnum\":\"1\",\"als_m3_cell_bank_orgnum\":\"3\",\"als_m6_cell_nbank_ca_allnum\":\"5\",\"als_m3_cell_caon_allnum\":\"12\",\"als_d15_id_bank_orgnum\":\"1\",\"als_m6_id_nbank_cf_orgnum\":\"6\",\"als_m1_id_nbank_p2p_allnum\":\"1\",\"als_m3_id_bank_allnum\":\"5\",\"als_m6_cell_bank_ret_orgnum\":\"2\",\"als_d15_id_caon_allnum\":\"7\",\"als_m3_id_nbank_cf_orgnum\":\"5\",\"als_m12_id_nbank_night_orgnum\":\"9\",\"flag_riskstrategy\":\"1\",\"als_m3_id_nbank_avg_monnum\":\"12.33\",\"als_m3_id_min_monnum\":\"7\",\"als_lst_cell_nbank_csinteday\":\"1\",\"als_m1_id_bank_night_orgnum\":\"0\",\"als_d7_id_nbank_allnum\":\"7\",\"als_m1_id_rel_orgnum\":\"3\",\"als_m1_cell_nbank_cf_orgnum\":\"3\",\"als_m6_id_nbank_oth_orgnum\":\"17\",\"als_d7_cell_nbank_ca_allnum\":\"1\",\"als_m1_id_nbank_p2p_orgnum\":\"1\",\"als_m12_id_nbank_orgnum\":\"29\",\"als_m3_id_nbank_night_allnum\":\"7\",\"als_d15_id_caoff_allnum\":\"2\",\"rs_ScoreAf_decision\":\"Accept\",\"flag_specialList_c\":\"0\",\"als_m3_cell_bank_selfnum\":\"0\",\"als_m6_id_nbank_p2p_allnum\":\"1\",\"als_m3_cell_nbank_cons_allnum\":\"16\",\"als_m3_id_bank_min_inteday\":\"0\",\"als_d7_id_nbank_orgnum\":\"7\",\"als_m6_cell_caon_orgnum\":\"17\",\"als_m12_id_bank_avg_monnum\":\"1.67\",\"als_m6_id_bank_night_allnum\":\"0\",\"als_m6_cell_bank_tot_mons\":\"5\",\"als_m3_id_caon_allnum\":\"17\",\"als_d7_cell_nbank_cons_allnum\":\"1\",\"als_d7_cell_nbank_week_orgnum\":\"0\",\"als_m12_id_min_inteday\":\"0\",\"als_m12_id_nbank_sloan_orgnum\":\"2\",\"als_m12_id_pdl_orgnum\":\"8\",\"als_m3_id_pdl_orgnum\":\"3\",\"als_m1_cell_bank_ret_allnum\":\"1\",\"als_m6_id_nbank_ca_allnum\":\"6\",\"rs_ScoreAf_scoreafcashon\":\"75\",\"als_m1_id_bank_tra_allnum\":\"1\",\"als_d15_id_nbank_orgnum\":\"14\",\"als_m6_cell_nbank_cf_orgnum\":\"6\",\"als_m12_cell_bank_night_allnum\":\"0\",\"als_m6_cell_nbank_tot_mons\":\"5\",\"als_d15_id_bank_tra_allnum\":\"1\",\"als_m6_cell_cooff_orgnum\":\"1\",\"als_m12_cell_bank_week_orgnum\":\"1\",\"als_m12_id_oth_orgnum\":\"1\",\"als_d7_id_nbank_oth_allnum\":\"5\",\"Rule_final_weight\":\"80\",\"als_m3_cell_bank_allnum\":\"4\",\"als_m6_cell_nbank_cons_orgnum\":\"10\",\"als_m6_id_coon_orgnum\":\"1\",\"als_d15_id_bank_tra_orgnum\":\"1\",\"als_d7_id_nbank_p2p_allnum\":\"1\",\"als_m12_id_nbank_cf_orgnum\":\"7\",\"rs_strategy_version\":\"1.0\",\"als_d15_cell_nbank_allnum\":\"11\",\"scoreafcashon\":\"75\",\"als_m6_id_nbank_finlea_orgnum\":\"1\",\"als_m12_id_oth_allnum\":\"1\",\"als_m12_id_max_inteday\":\"34\",\"als_m1_id_nbank_oth_allnum\":\"12\",\"als_m6_cell_bank_selfnum\":\"0\",\"als_m1_cell_nbank_nsloan_allnum\":\"2\",\"als_m1_cell_coon_allnum\":\"1\",\"als_m1_cell_nbank_selfnum\":\"0\",\"als_m1_cell_pdl_allnum\":\"2\",\"als_m12_id_cooff_allnum\":\"4\",\"als_m6_id_nbank_night_allnum\":\"10\",\"als_d15_id_bank_week_orgnum\":\"0\",\"als_m1_cell_caon_orgnum\":\"7\",\"als_m6_id_nbank_avg_monnum\":\"12.20\",\"als_m12_id_bank_tot_mons\":\"9\",\"als_m1_cell_coon_orgnum\":\"1\",\"als_m6_cell_nbank_cf_allnum\":\"19\",\"als_m1_cell_nbank_nsloan_orgnum\":\"2\",\"als_d7_id_nbank_finlea_allnum\":\"1\",\"als_m6_id_nbank_sloan_orgnum\":\"2\",\"als_m1_cell_pdl_orgnum\":\"2\",\"als_d7_id_caoff_allnum\":\"2\",\"als_m1_cell_rel_allnum\":\"2\",\"als_m3_cell_bank_tot_mons\":\"2\",\"als_m3_cell_bank_ret_allnum\":\"2\",\"als_m12_id_nbank_max_inteday\":\"50\",\"als_m6_cell_max_inteday\":\"16\",\"als_m6_id_caon_allnum\":\"30\",\"als_m6_id_nbank_night_orgnum\":\"9\",\"als_m3_cell_cooff_orgnum\":\"1\",\"als_m6_id_bank_max_inteday\":\"52\",\"als_m12_id_bank_min_inteday\":\"0\",\"als_m3_cell_bank_ret_orgnum\":\"1\",\"als_m3_cell_nbank_max_monnum\":\"15\",\"als_m1_id_nbank_oth_orgnum\":\"11\",\"als_m6_id_nbank_sloan_allnum\":\"4\",\"als_d7_id_nbank_finlea_orgnum\":\"1\",\"als_m1_cell_rel_orgnum\":\"2\",\"als_m6_cell_bank_min_inteday\":\"0\",\"als_m12_cell_nbank_min_inteday\":\"0\",\"als_m3_cell_cooff_allnum\":\"1\",\"als_d15_id_bank_week_allnum\":\"0\",\"als_m6_id_caon_orgnum\":\"19\",\"als_m6_id_nbank_p2p_orgnum\":\"1\",\"als_m6_cell_cooff_allnum\":\"2\",\"als_m3_id_cooff_allnum\":\"2\",\"als_m12_cell_caoff_allnum\":\"6\",\"als_m6_cell_min_inteday\":\"0\",\"als_m6_id_cooff_allnum\":\"3\",\"als_m6_id_caoff_allnum\":\"4\",\"als_m1_cell_caon_allnum\":\"7\",\"als_m12_id_caon_orgnum\":\"19\",\"als_m12_id_nbank_nsloan_allnum\":\"28\",\"als_m6_cell_caoff_allnum\":\"4\",\"als_m6_cell_nbank_week_orgnum\":\"5\",\"als_d7_cell_nbank_nsloan_orgnum\":\"2\",\"als_m3_cell_rel_orgnum\":\"5\",\"als_m6_cell_rel_orgnum\":\"5\",\"als_m12_id_nbank_oth_orgnum\":\"17\",\"als_m12_id_coon_allnum\":\"2\",\"als_d15_cell_nbank_p2p_allnum\":\"1\",\"als_m12_id_nbank_cons_allnum\":\"33\",\"als_m3_id_nbank_sloan_allnum\":\"2\",\"als_m12_cell_avg_monnum\":\"6.42\",\"als_d15_id_nbank_cf_allnum\":\"3\",\"als_m3_cell_max_inteday\":\"13\",\"als_m12_cell_cooff_allnum\":\"3\",\"als_m3_id_bank_avg_monnum\":\"2.50\",\"Rule_final_decision\":\"Reject\",\"flag_applyloanstr\":\"1\",\"als_d15_cell_nbank_oth_allnum\":\"8\",\"als_m6_cell_bank_night_allnum\":\"0\",\"als_d7_cell_coon_orgnum\":\"1\",\"als_m6_id_nbank_ca_orgnum\":\"4\",\"als_d7_cell_nbank_week_allnum\":\"0\",\"als_m6_id_bank_week_orgnum\":\"1\",\"als_m1_id_nbank_else_allnum\":\"4\",\"als_m1_cell_bank_ret_orgnum\":\"1\",\"als_m12_id_nbank_week_orgnum\":\"7\",\"als_m3_cell_nbank_tot_mons\":\"3\",\"als_m3_id_bank_ret_orgnum\":\"1\",\"als_d15_cell_caoff_allnum\":\"2\",\"als_m3_id_nbank_finlea_orgnum\":\"1\",\"als_m3_cell_bank_avg_monnum\":\"2.00\",\"als_m12_cell_nbank_week_allnum\":\"14\",\"als_m1_cell_nbank_ca_orgnum\":\"1\",\"als_m1_id_caon_allnum\":\"9\",\"als_m12_id_nbank_week_allnum\":\"14\",\"als_m6_cell_bank_min_monnum\":\"0\",\"als_d15_cell_caoff_orgnum\":\"2\",\"als_m3_cell_nbank_min_inteday\":\"0\",\"als_d15_id_nbank_finlea_allnum\":\"1\",\"als_m12_id_nbank_allnum\":\"75\",\"als_m3_cell_avg_monnum\":\"11.00\",\"als_m6_id_nbank_tot_mons\":\"5\",\"als_m12_cell_nbank_oth_orgnum\":\"14\",\"als_m1_cell_nbank_ca_allnum\":\"1\",\"als_m3_cell_bank_min_inteday\":\"0\",\"als_d15_cell_nbank_p2p_orgnum\":\"1\",\"als_m12_cell_pdl_allnum\":\"23\",\"als_m6_cell_caon_allnum\":\"24\",\"rs_platform\":\"web\",\"als_m1_cell_nbank_finlea_allnum\":\"1\",\"als_m12_id_nbank_tot_mons\":\"11\",\"als_m12_id_pdl_allnum\":\"25\",\"als_m6_id_cooff_orgnum\":\"2\",\"als_m3_id_cooff_orgnum\":\"2\",\"als_m3_id_nbank_night_orgnum\":\"6\",\"als_m12_id_nbank_min_inteday\":\"0\",\"als_m6_cell_bank_allnum\":\"8\",\"als_m1_id_nbank_else_orgnum\":\"4\",\"als_m6_cell_nbank_week_allnum\":\"11\",\"rs_scene\":\"lend\",\"als_m12_id_caon_allnum\":\"36\",\"als_m6_id_caoff_orgnum\":\"3\",\"als_m12_cell_pdl_orgnum\":\"6\",\"als_m3_id_caoff_orgnum\":\"3\",\"als_m12_cell_caoff_orgnum\":\"3\",\"als_m6_cell_bank_max_monnum\":\"3\",\"als_m3_id_nbank_min_inteday\":\"0\",\"als_m6_cell_bank_max_inteday\":\"52\",\"als_m3_id_nbank_nsloan_orgnum\":\"8\",\"als_m12_cell_coon_orgnum\":\"1\",\"als_m6_cell_bank_orgnum\":\"6\",\"als_m3_id_nbank_nsloan_allnum\":\"14\",\"als_m12_cell_cooff_orgnum\":\"2\",\"als_m3_id_pdl_allnum\":\"9\",\"als_m12_cell_nbank_oth_allnum\":\"27\",\"als_m3_id_caoff_allnum\":\"3\",\"als_d15_id_nbank_cf_orgnum\":\"3\",\"als_d7_cell_caon_orgnum\":\"4\",\"als_m6_cell_avg_monnum\":\"9.67\",\"als_m6_cell_nbank_p2p_orgnum\":\"1\",\"als_m12_cell_nbank_night_allnum\":\"8\",\"als_m6_id_bank_min_inteday\":\"0\",\"als_d15_cell_nbank_cf_orgnum\":\"1\",\"als_m6_id_nbank_week_allnum\":\"11\",\"als_m1_cell_nbank_finlea_orgnum\":\"1\",\"als_m6_cell_bank_night_orgnum\":\"0\",\"als_d15_id_pdl_orgnum\":\"2\",\"rs_final_decision\":\"Reject\",\"als_d7_cell_caon_allnum\":\"4\",\"als_m1_id_nbank_selfnum\":\"0\",\"als_m1_id_caon_orgnum\":\"9\",\"als_m3_cell_bank_min_monnum\":\"0\",\"als_m12_cell_nbank_finlea_orgnum\":\"1\",\"als_m6_id_nbank_cf_allnum\":\"21\",\"als_m6_id_bank_max_monnum\":\"4\",\"als_m6_id_nbank_week_orgnum\":\"5\",\"als_m3_id_bank_ret_allnum\":\"2\",\"als_m6_id_bank_orgnum\":\"8\",\"als_m6_cell_bank_avg_monnum\":\"1.60\",\"als_m3_cell_nbank_min_monnum\":\"5\",\"als_d7_id_caon_allnum\":\"4\",\"als_m3_id_nbank_finlea_allnum\":\"1\",\"als_m6_id_min_inteday\":\"0\",\"als_d7_cell_nbank_finlea_orgnum\":\"1\",\"als_lst_cell_bank_consnum\":\"1\",\"als_m6_id_nbank_max_inteday\":\"14\",\"als_m1_id_bank_ret_orgnum\":\"1\",\"als_d15_cell_nbank_ca_allnum\":\"1\",\"als_m12_cell_caon_orgnum\":\"17\",\"als_d15_cell_nbank_week_orgnum\":\"0\",\"als_m6_cell_bank_week_allnum\":\"1\",\"als_d15_id_nbank_finlea_orgnum\":\"1\",\"als_m12_id_nbank_finlea_allnum\":\"1\",\"als_m1_cell_nbank_sloan_orgnum\":\"1\",\"als_m1_cell_nbank_else_orgnum\":\"4\",\"als_m3_cell_rel_allnum\":\"7\",\"als_m6_id_nbank_max_monnum\":\"19\",\"als_m12_id_nbank_nsloan_orgnum\":\"9\",\"als_m12_cell_nbank_cons_allnum\":\"32\",\"als_d15_cell_nbank_oth_orgnum\":\"8\",\"als_d7_id_nbank_ca_orgnum\":\"1\",\"als_m12_cell_nbank_tot_mons\":\"11\",\"als_m6_cell_rel_allnum\":\"10\",\"als_m12_cell_nbank_week_orgnum\":\"7\",\"als_m6_cell_caoff_orgnum\":\"3\",\"als_m3_cell_coon_orgnum\":\"1\",\"als_d15_cell_nbank_cons_orgnum\":\"5\",\"als_m6_cell_coon_allnum\":\"2\",\"als_m12_id_coon_orgnum\":\"1\",\"als_d7_id_coon_allnum\":\"1\",\"als_m12_id_nbank_finlea_orgnum\":\"1\",\"als_m6_id_bank_allnum\":\"10\",\"als_m6_id_bank_week_allnum\":\"1\",\"als_m6_id_nbank_cons_orgnum\":\"11\",\"als_m3_id_nbank_week_orgnum\":\"2\",\"als_m12_id_bank_night_allnum\":\"0\",\"als_m12_cell_nbank_p2p_allnum\":\"1\",\"als_d7_cell_coon_allnum\":\"1\",\"als_m3_id_bank_night_orgnum\":\"0\",\"als_m3_cell_coon_allnum\":\"2\",\"als_m3_id_nbank_min_monnum\":\"7\",\"als_d15_id_nbank_nsloan_allnum\":\"4\",\"als_d15_cell_nbank_cons_allnum\":\"5\",\"als_m12_id_bank_max_monnum\":\"4\",\"als_fst_cell_nbank_inteday\":\"342\",\"als_m3_id_nbank_week_allnum\":\"4\",\"als_m12_cell_nbank_p2p_orgnum\":\"1\",\"als_m12_cell_nbank_finlea_allnum\":\"1\",\"als_m6_id_nbank_cons_allnum\":\"26\",\"als_m12_cell_max_inteday\":\"34\",\"als_m6_cell_nbank_min_inteday\":\"0\",\"als_m12_id_nbank_min_monnum\":\"0\",\"als_lst_cell_nbank_consnum\":\"1\",\"als_m3_cell_nbank_week_orgnum\":\"2\",\"als_m12_cell_bank_max_inteday\":\"66\",\"als_d7_cell_nbank_nsloan_allnum\":\"2\",\"als_m12_cell_bank_min_monnum\":\"0\",\"queryTime\":\"2023-10-24 19:20:24\",\"als_m3_cell_nbank_avg_monnum\":\"9.67\",\"als_m12_id_bank_night_orgnum\":\"0\",\"als_m3_cell_nbank_week_allnum\":\"4\"},\"RONG360_BLACK_LIST\":{\"flag\":\"1\",\"data\":{\"tianji_api_pudao_getResult_response\":{\"feature2\":\"\",\"feature3\":\"\",\"feature4\":\"\",\"feature5\":[\"1\"],\"feature1\":\"1\"},\"error\":\"200\",\"request_id\":\"16881405569394946687\"},\"resp_cd\":\"000000\",\"queryTime\":\"2023-10-24 19:20:25\",\"resp_msg\":\"处理成功\",\"unif_mult_label_score_v2_ex_v1.0_s1815\":{\"flag\":\"1\",\"resp_cd\":\"000000\",\"resp_msg\":\"处理成功\"},\"rqst_id\":\"20231024192022119101\",\"comprs\":\"0\"}}";
        JSONObject jsonObject = JSONObject.parseObject(a);

        log.info("jsonObject:[{}]", jsonObject.toJSONString());
        Set<String> keys = jsonObject.keySet();
        log.info("keys:[{}]", JSONObject.toJSONString(keys));
    }
}
